@@ -154,7 +154,7 @@ class CloudPods:
             "bios": bios
         }
         if hypervisor == "kvm":
-            server["guest_image_id"]=disk_image_id
+            server["guest_image_id"]=guest_image_id
             server["sku"] = sku
             server["schedtags"] = [{"id": "094cfe0f-7fbf-451f-879d-d44151539240", "strategy": "exclude"}]
             server["disks"] = [{"disk_type": "sys", "index": 0, "backend": "local", "size": disk_size, "image_id": disk_image_id,
@@ -169,7 +169,7 @@ class CloudPods:
                 server["disks"].append(disk)
         if hypervisor == "baremetal":
             server["disks"] = [
-                        {"size":40960,"image_id":guest_image_id},
+                        {"size":40960,"image_id":disk_image_id},
                         {"size":-1,"fs":"ext4","mountpoint":"/opt/cloud/workspace"}
                       ]
             server["vcpu_count"]=cpu
